@@ -5,13 +5,15 @@ import pytest
 from voluptuous import (
     All,
     Any,
-    Coerce,  # type: ignore
+    Coerce,
     Range,
     Schema,
 )
 
-from kasa import EmeterStatus, SmartDeviceException
-from kasa.modules.emeter import Emeter
+from kasa import Device, EmeterStatus, Module
+from kasa.interfaces.energy import Energy
+from kasa.iot import IotDevice, IotStrip
+from kasa.iot.modules.emeter import Emeter
 
 from .conftest import has_emeter, has_emeter_iot, no_emeter
 
@@ -19,14 +21,14 @@ CURRENT_CONSUMPTION_SCHEMA = Schema(
     Any(
         {
             "voltage": Any(All(float, Range(min=0, max=300)), None),
-            "power": Any(Coerce(float, Range(min=0)), None),
-            "total": Any(Coerce(float, Range(min=0)), None),
-            "current": Any(All(float, Range(min=0)), None),
+            "power": Any(Coerce(float), None),
+            "total": Any(Coerce(float), None),
+            "current": Any(All(float), None),
             "voltage_mv": Any(All(float, Range(min=0, max=300000)), int, None),
-            "power_mw": Any(Coerce(float, Range(min=0)), None),
-            "total_wh": Any(Coerce(float, Range(min=0)), None),
-            "current_ma": Any(All(float, Range(min=0)), int, None),
-            "slot_id": Any(Coerce(int, Range(min=0)), None),
+            "power_mw": Any(Coerce(float), None),
+            "total_wh": Any(Coerce(float), None),
+            "current_ma": Any(All(float), int, None),
+            "slot_id": Any(Coerce(int), None),
         },
         None,
     )
@@ -37,14 +39,17 @@ CURRENT_CONSUMPTION_SCHEMA = Schema(
 async def test_no_emeter(dev):
     assert not dev.has_emeter
 
-    with pytest.raises(SmartDeviceException):
+    with pytest.raises(AttributeError):
         await dev.get_emeter_realtime()
-    with pytest.raises(SmartDeviceException):
-        await dev.get_emeter_daily()
-    with pytest.raises(SmartDeviceException):
-        await dev.get_emeter_monthly()
-    with pytest.raises(SmartDeviceException):
-        await dev.erase_emeter_stats()
+    # Only iot devices support the historical stats so other
+    # devices will not implement the methods below
+    if isinstance(dev, IotDevice):
+        with pytest.raises(AttributeError):
+            await dev.get_emeter_daily()
+        with pytest.raises(AttributeError):
+            await dev.get_emeter_monthly()
+        with pytest.raises(AttributeError):
+            await dev.erase_emeter_stats()
 
 
 @has_emeter
@@ -121,14 +126,14 @@ async def test_erase_emeter_stats(dev):
     await dev.erase_emeter()
 
 
-@has_emeter
+@has_emeter_iot
 async def test_current_consumption(dev):
     if dev.has_emeter:
-        x = await dev.current_consumption()
+        x = dev.current_consumption
         assert isinstance(x, float)
         assert x >= 0.0
     else:
-        assert await dev.current_consumption() is None
+        assert dev.current_consumption is None
 
 
 async def test_emeterstatus_missing_current():
@@ -169,3 +174,30 @@ async def test_emeter_daily():
         {"day": now.day, "energy_wh": 500, "month": now.month, "year": now.year}
     )
     assert emeter.emeter_today == 0.500
+
+
+@has_emeter
+async def test_supported(dev: Device):
+    energy_module = dev.modules.get(Module.Energy)
+    assert energy_module
+    if isinstance(dev, IotDevice):
+        info = (
+            dev._last_update
+            if not isinstance(dev, IotStrip)
+            else dev.children[0].internal_state
+        )
+        emeter = info[energy_module._module]["get_realtime"]
+        has_total = "total" in emeter or "total_wh" in emeter
+        has_voltage_current = "voltage" in emeter or "voltage_mv" in emeter
+        assert (
+            energy_module.supports(Energy.ModuleFeature.CONSUMPTION_TOTAL) is has_total
+        )
+        assert (
+            energy_module.supports(Energy.ModuleFeature.VOLTAGE_CURRENT)
+            is has_voltage_current
+        )
+        assert energy_module.supports(Energy.ModuleFeature.PERIODIC_STATS) is True
+    else:
+        assert energy_module.supports(Energy.ModuleFeature.CONSUMPTION_TOTAL) is False
+        assert energy_module.supports(Energy.ModuleFeature.VOLTAGE_CURRENT) is False
+        assert energy_module.supports(Energy.ModuleFeature.PERIODIC_STATS) is False
